@@ -186,6 +186,9 @@ class Expression(numbers.Number):
 
         return grads
 
+    def diff(self, variable: Variable):
+        return self.expr.diff(variable)
+
     @property
     def value(self):
         return self.__call__()
@@ -202,10 +205,6 @@ class Expression(numbers.Number):
         eq = lhs + " = " + rhs
         if not evaluate:
             return eq
-        #         try:
-        #             res = sympy.Float(self.__call__(version), G.float_digit)
-        #         except TypeError:
-        #             res = self.__call__(version)
 
         res = self.__call__(version)
 
